Module args

Module args 

A forc plugin for converting a given string or path to their hash.

Structs

HashArgs

Functions

examples
read_content_filepath_or_stdin
Reads the arg and returns a vector of bytes